[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
[![LinkedIn][linkedin-shield]][linkedin-url]



<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/Vania-Dev">
    <img src="images/SMAEPYP.png" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center">PyToNotion</h3>

  <a href="https://github.com/Vania-Dev">
    <img src="images/header.png" alt="Logo" style="height: 60%; width:60%;">
  </a>

  <p align="center">
    Un repositorio para la paqueteria de PyToNotion
    <br />
    <br />
    <a href="https://github.com/Vania-Dev/PyToNotion">Material adicional</a>
    ·
    <a href="https://github.com/Vania-Dev/PyToNotion/issues/new?labels=bug&template=bug-report---.md">Reportar un Error</a>
    ·
    <a href="https://github.com/Vania-Dev/PyToNotion/issues/new?labels=enhancement&template=feature-request---.md">Solicitar una mejora</a>
  </p>
</div>



<!-- TABLE OF CONTENTS -->
<details>
  <summary>Tabla de contenido</summary>
  <ol>
    <li>
      <a href="#acerca-del-proyecto">Acerca del proyecto</a>
      <ul>
        <li><a href="#construido-con">Construido con</a></li>
      </ul>
    </li>
    <li><a href="#lista-de-videos">Lista de Videos</a></li>
    <li>
      <a href="#comienza-a-usarlo">Comienza a usarlo</a>
      <ul>
        <li><a href="#prerequisitos">Prerequisitos</a></li>
        <li><a href="#instalación">Instalación</a></li>
      </ul>
    </li>
    <li><a href="#contribución">Contribución</a></li>
    <li><a href="#licencia">Licencia</a></li>
    <li><a href="#contacto">Contacto</a></li>
  </ol>
</details>



<!-- ABOUT THE PROJECT -->
## Acerca Del Proyecto

Este repositorio cuenta con el código de la paqueteria PyToNotion, es la paqueteria de Python para conectarse con Notion y cuenta con ejemplos de como usar cada una de las funciones.

### Construido Con

El proyecto esta creado en el lenguaje de programación Python en su versión 3.12.X

* [![Python][Python]][Python-url]

## Lista de Videos

- En proceso

<!-- GETTING STARTED -->
## Comienza A Usarlo

Este es un ejemplo de como logar ejecutar el proyecto y sus funciones internas, es necesario instalar la paqueteria o clonar el proyecto en tu local.

### Prerequisitos

Esta es la lista de blibliotecas o paqueterias que debes instalar para ejecutar el proyecto de forma adecuada.
* pip
  ```sh
  pip install -r requirements.txt
  ```

### Instalación

_Abajo se muestra una guía para la instalación del repositorio_

1. Clonar el repositorio
   ```sh
   git clone https://github.com/your_username_/PyToNotion.git
   ```
2. Instalar las paqueterias
   ```sh
   pip install -r requirements.txt
   ```
3. Instalar la paqueteria
   ```sh
   pip install PyToNotion
   ```


<!-- CONTRIBUTING -->
## Contribución

La contibución hace que la comunidad del open source sea un gran lugar para aprender, inspirar y crear. Cualquier contribución que realices sera **muy agradecida**

Si tienes una sugerencia para mejorar el proyecto, por favor realiza un fork al repositorio y crea un pull request. Tambien puedes hacer algo an simple como abrir una incidencia con el tag "mejora".

No olvides darle una estrella al repositorio :D! Muchas Gracias!


1. Realiza un fork al proyecto
2. Crea tu rama (`git checkout -b feature/AmazingFeature`)
3. Realiza tus cambios con commit (`git commit -m 'Add some AmazingFeature'`)
4. Sube tu rama (`git push origin feature/AmazingFeature`)
5. Abre un Pull Request


<!-- LICENSE -->
## Licencia

Distribuido bajo la licencia MIT. Mira el archivo `LICENSE.txt` para más información.

<!-- CONTACT -->
## Contacto

Mi contacto - [VCard](https://vcard.idkey.com.mx/pmobnj7/)

Link de VaniaDev: [https://vaniadev.super.site/](https://vaniadev.super.site/)


<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[contributors-shield]: https://img.shields.io/github/contributors/Vania-Dev/PyToNotion.svg?style=for-the-badge
[contributors-url]: https://github.com/Vania-Dev/PyToNotion/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/Vania-Dev/PyToNotion.svg?style=for-the-badge
[forks-url]: https://github.com/Vania-Dev/PyToNotion/network/members
[stars-shield]: https://img.shields.io/github/stars/Vania-Dev/PyToNotion.svg?style=for-the-badge
[stars-url]: https://github.com/Vania-Dev/PyToNotion/stargazers
[issues-shield]: https://img.shields.io/github/issues/Vania-Dev/PyToNotion.svg?style=for-the-badge
[issues-url]: https://github.com/Vania-Dev/PyToNotion/issues
[license-shield]: https://img.shields.io/github/license/Vania-Dev/PyToNotion.svg?style=for-the-badge
[license-url]: https://github.com/Vania-Dev/PyToNotion/blob/master/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://www.linkedin.com/in/ivan-casta%C3%B1eda/
[Python]: https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54
[Python-url]: https://www.python.org